.. figure:: images/AiiDA_transparent_logo.png
    :width: 250px
    :align: center

The aiida-raspa plugin for `AiiDA`_
=====================================================

``aiida-raspa`` is available at http://github.com/yakutovicha/aiida-raspa


.. toctree::
   :maxdepth: 1

   workflows


   API documentation <apidoc/aiida_raspa>

If you use this plugin for your research, please cite the following work:

.. highlights:: Daniele Ongari, Aliksandr V. Yakutovich, Leopold Talirz, and Berend Smit,
  *Building a Consistent and Reproducible Database for Adsorption Evaluation in Covalent–Organic Frameworks*,
  ACS Cent. Sci. 2019, 5, 10, 1663-1675 (2019);
  https://doi.org/10.1021/acscentsci.9b00619.

If you use AiiDA for your research, please cite the following work:

.. highlights:: Giovanni Pizzi, Andrea Cepellotti, Riccardo Sabatini, Nicola Marzari,
  and Boris Kozinsky, *AiiDA: automated interactive infrastructure and database
  for computational science*, Comp. Mat. Sci 111, 218-230 (2016);
  https://doi.org/10.1016/j.commatsci.2015.09.013; http://www.aiida.net.

``aiida-raspa`` is released under the MIT license.




Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _AiiDA: http://www.aiida.net
